@@ -382,7 +382,7 @@ def main():
     
                     if values_m3[5] is True:
                         active_site = 'YES'
-                    elif values_m3[5] is False and len(values_m3[6] > 0):
+                    elif values_m3[5] is False and len(values_m3[6]) > 0:
                         active_site = values_m3[6].replace(" ", "").split(",")
                     else:
                         checks.append("Error: Untick the box or indicate the active site residues!")
